<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelExtratoConsumidor  {

    protected $RelExtratoConsumidorService;
    protected $utilService;
    
    public function __construct(Services\RelExtratoConsumidorService $RelExtratoConsumidorService, Utilities\Util $utilService) {
        $this->RelExtratoConsumidorService = $RelExtratoConsumidorService;
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])) {
            $conditions = $this->buildParams($conditions);
            if($conditions['TIPORELATORIO'] == 'S') {
                $result = $this->RelExtratoConsumidorService->findSintetico($conditions['CDFILIAL'], $conditions['CDTIPOCONS'], $conditions['DTLANCINI'], $conditions['DTLANCFIN'], $conditions['CDLOJA'], $conditions['CDCONSUMIDOR'], $conditions['NOMEINI'], $conditions['NOMEFIM'], $conditions['TCDCLIENTE'], $conditions['TCDCONSUMIDOR'], $conditions['TCDLOJA'], $conditions['TCDTIPOCONS'], $conditions['CDCLIENTE'], $conditions['TIPOSALDO']);
            } else {
                $result = $this->RelExtratoConsumidorService->findAnalitico($conditions['CDFILIAL'], $conditions['CDTIPOCONS'], $conditions['DTLANCINI'], $conditions['DTLANCFIN'], $conditions['CDLOJA'], $conditions['CDCONSUMIDOR'], $conditions['NOMEINI'], $conditions['NOMEFIM'], $conditions['TCDCLIENTE'], $conditions['TCDCONSUMIDOR'], $conditions['TCDLOJA'], $conditions['TCDTIPOCONS'], $conditions['CDCLIENTE'], $conditions['TIPOSALDO']);
            }
        }
        
        $response->addDataSet(new DataSet("RelExtratoConsumidor", $result));
        
        return $response;
    }

    public function buildParams($conditions){
        $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
        
        if(empty($conditions['CDLOJA'])) {
            $conditions['CDLOJA'] = '';
            $conditions['TCDLOJA'] = 'T';
        } else {
            $conditions['CDLOJA'] = implode('_', $conditions['CDLOJA']);
            $conditions['TCDLOJA'] = '';
        }
        
        if(empty($conditions['CDTIPOCONS'])) {
            $conditions['CDTIPOCONS'] = '';
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = implode('_', $conditions['CDTIPOCONS']);
            $conditions['TCDTIPOCONS'] = '';
        }
        
        if(empty($conditions['CDCLIENTE'])) {
            $conditions['CDCLIENTE'] = '';
            $conditions['TCDCLIENTE'] = 'T';
        } else {
            $conditions['CDCLIENTE'] = implode('_', $conditions['CDCLIENTE']);
            $conditions['TCDCLIENTE'] = '';
        }
        
        if(empty($conditions['CDCONSUMIDOR'])) {
            $conditions['CDCONSUMIDOR'] = '';
            $conditions['TCDCONSUMIDOR'] = 'T';
        } else {
            $conditions['CDCONSUMIDOR'] = implode('_', $conditions['CDCONSUMIDOR']);
            $conditions['TCDCONSUMIDOR'] = '';
        }
        
        if(empty($conditions['NOMEINI'])) {
            $conditions['NOMEINI'] = '';
            $conditions['NOMEFIM'] = '';
        }
        
        $conditions['DTLANCINI'] = $conditions['DTENTRVENDA'][0];
        $conditions['DTLANCFIN'] = $conditions['DTENTRVENDA'][1];
        
        return $conditions;
    }
    
    public function findConsumidor(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
        
        if(empty($conditions['CDTIPOCONS'])) {
            $conditions['CDTIPOCONS'] = '';
            $conditions['TCDTIPOCONS'] = 'T';
        } else {
            $conditions['CDTIPOCONS'] = implode('_', $conditions['CDTIPOCONS']);
            $conditions['TCDTIPOCONS'] = '';
        }
        
        if(empty($conditions['CDCLIENTE'])) {
            $conditions['CDCLIENTE'] = '';
            $conditions['TCDCLIENTE'] = 'T';
        } else {
            $conditions['CDCLIENTE'] = implode('_', $conditions['CDCLIENTE']);
            $conditions['TCDCLIENTE'] = '';
        }
        
        if(empty($conditions['NOMEINI'])) {
            $conditions['NOMEINI'] = '';
            $conditions['NOMEFIM'] = '';
        }
        
        $result = $this->RelExtratoConsumidorService->findConsumidor($conditions['CDFILIAL'], $conditions['CDCLIENTE'], $conditions['TCDCLIENTE'], $conditions['NOMEINI'], $conditions['NOMEFIM'], $conditions['CDTIPOCONS'], $conditions['TCDTIPOCONS']);
                
        $response->addDataSet(new DataSet("relExtConsConsumidor", $result));
        
        return $response;
    }
    
}
